@@ -507,7 +507,7 @@ int DirTree::parent(unsigned index)
     // and check if one of the children is 'index'
     for (unsigned j = 0; j < entryCount(); j++) {
         std::vector<unsigned> chi = children(j);
-        for (unsigned i = 0; i < chi.size();i++)
+        for (unsigned i = 0; i < chi.size(); i++)
             if (chi[i] == index)
                 return j;
     }
@@ -684,10 +684,12 @@ void DirTree::load(unsigned char* buffer, unsigned size)
 
         // sanity checks
         if ((type != 2) && (type != 1) && (type != 5)) e.valid = false;
+        if (name_len < 1) e.valid = false;
 
-        // the spec do not deny items with an empty name even if it makes not
-        // really sense cause the item cannot access then by name.
-        //if (name_len < 1) e.valid = false;
+        // CLSID, contains a object class GUI if this entry is a storage or root
+        // storage or all zero if not.
+        printf("DirTree::load name=%s type=%i prev=%i next=%i child=%i start=%lu size=%lu clsid=%lu.%lu.%lu.%lu\n",
+               name.c_str(), type, e.prev, e.next, e.child, e.start, e.size, readU32(buffer + 0x50 + p), readU32(buffer + 0x54 + p), readU32(buffer + 0x58 + p), readU32(buffer + 0x5C + p));
 
         entries.push_back(e);
     }
@@ -825,6 +827,10 @@ void StorageIO::load()
     buffer = new unsigned char[512];
     file.seekg(0);
     file.read((char*)buffer, 512);
+    if (!file.good()) {
+        delete[] buffer;
+        return;
+    }
     header->load(buffer);
     delete[] buffer;
 
@@ -855,7 +861,11 @@ void StorageIO::load()
         unsigned k = 109;
         unsigned mblock = header->mbat_start;
         for (unsigned r = 0; r < header->num_mbat; r++) {
-            loadBigBlock(mblock, buffer2, bbat->blockSize);
+            unsigned long rr = loadBigBlock(mblock, buffer2, bbat->blockSize);
+            if (rr != bbat->blockSize) {
+                delete[] buffer2;
+                return;
+            }
             for (unsigned s = 0; s < bbat->blockSize - 4; s += 4) {
                 if (k >= header->num_bat) break;
                 else  blocks[k++] = readU32(buffer2 + s);
@@ -869,7 +879,11 @@ void StorageIO::load()
     buflen = blocks.size() * bbat->blockSize;
     if (buflen > 0) {
         buffer = new unsigned char[ buflen ];
-        loadBigBlocks(blocks, buffer, buflen);
+        unsigned long r = loadBigBlocks(blocks, buffer, buflen);
+        if (r != buflen) {
+            delete[] buffer;
+            return;
+        }
         bbat->load(buffer, buflen);
         delete[] buffer;
     }
@@ -880,7 +894,11 @@ void StorageIO::load()
     buflen = blocks.size() * bbat->blockSize;
     if (buflen > 0) {
         buffer = new unsigned char[ buflen ];
-        loadBigBlocks(blocks, buffer, buflen);
+        unsigned long r = loadBigBlocks(blocks, buffer, buflen);
+        if (r != buflen) {
+            delete[] buffer;
+            return;
+        }
         sbat->load(buffer, buflen);
         delete[] buffer;
     }
@@ -890,7 +908,11 @@ void StorageIO::load()
     blocks = bbat->follow(header->dirent_start);
     buflen = blocks.size() * bbat->blockSize;
     buffer = new unsigned char[ buflen ];
-    loadBigBlocks(blocks, buffer, buflen);
+    unsigned long r = loadBigBlocks(blocks, buffer, buflen);
+    if (r != buflen) {
+        delete[] buffer;
+        return;
+    }
     dirtree->load(buffer, buflen);
     unsigned sb_start = readU32(buffer + 0x74);
     delete[] buffer;
@@ -984,6 +1006,7 @@ unsigned long StorageIO::loadBigBlocks(std::vector<unsigned long> blocks,
         if (pos + p > filesize) p = filesize - pos;
         file.seekg(pos);
         file.read((char*)data + bytes, p);
+        if (!file.good()) return 0;
         bytes += p;
     }
 
@@ -1028,7 +1051,11 @@ unsigned long StorageIO::loadSmallBlocks(std::vector<unsigned long> blocks,
         unsigned long bbindex = pos / bbat->blockSize;
         if (bbindex >= sb_blocks.size()) break;
 
-        loadBigBlock(sb_blocks[ bbindex ], buf, bbat->blockSize);
+        unsigned long r = loadBigBlock(sb_blocks[ bbindex ], buf, bbat->blockSize);
+        if (r != bbat->blockSize) {
+            delete[] buf;
+            return 0;
+        }
 
         // copy the data
         unsigned offset = pos % bbat->blockSize;
@@ -1154,7 +1181,11 @@ unsigned long StreamIO::read(unsigned long pos, unsigned char* data, unsigned lo
         unsigned long offset = pos % io->bbat->blockSize;
         while (totalbytes < maxlen) {
             if (index >= blocks.size()) break;
-            io->loadBigBlock(blocks[index], buf, io->bbat->blockSize);
+            unsigned long r = io->loadBigBlock(blocks[index], buf, io->bbat->blockSize);
+            if (r != io->bbat->blockSize) {
+                delete [] buf;
+                return 0;
+            }
             unsigned long count = io->bbat->blockSize - offset;
             if (count > maxlen - totalbytes) count = maxlen - totalbytes;
             memcpy(data + totalbytes, buf + offset, count);
@@ -1220,13 +1251,14 @@ std::list<std::string> Storage::entries(const std::string& path)
     std::list<std::string> result;
     DirTree* dt = io->dirtree;
     DirEntry* e = dt->entry(path, false);
-    if (e  && e->dir) {
-        unsigned parent = dt->indexOf(e);
-        std::vector<unsigned> children = dt->children(parent);
-        for (unsigned i = 0; i < children.size(); i++)
-            result.push_back(dt->entry(children[i])->name);
+    if (e) {
+        if (e->dir) {
+            unsigned parent = dt->indexOf(e);
+            std::vector<unsigned> children = dt->children(parent);
+            for (unsigned i = 0; i < children.size(); i++)
+                result.push_back(dt->entry(children[i])->name);
+        }
     }
-
     return result;
 }
 
