@@ -359,6 +359,7 @@ KoFilter::ConversionStatus DocxXmlStylesReader::read_style()
         }
         else if (type == "table") {
             m_currentTableStyle = KoGenStyle(KoGenStyle::TableStyle, odfType.toLatin1());
+            m_currentTableCellStyle = KoGenStyle(KoGenStyle::TableCellStyle, "table-cell");
         }
     }
     MSOOXML::Utils::Setter<bool> currentTextStylePredefinedSetter(&m_currentTextStylePredefined, false);
@@ -473,6 +474,9 @@ KoFilter::ConversionStatus DocxXmlStylesReader::read_style()
         }
         else if (type == "table") {
             styleName = mainStyles->insert(m_currentTableStyle, styleName, insertionFlags);
+            if (!m_currentTableCellStyle.isEmpty()) {
+                mainStyles->insert(m_currentTableCellStyle, QString("%1-%2").arg(styleName).arg("cells"), insertionFlags);
+            }
         }
         if (!nextStyleName.isEmpty()) {
             mainStyles->insertStyleRelation(styleName, nextStyleName, "style:next-style-name");
