@@ -46,15 +46,18 @@ MsooXmlCommonReader::MsooXmlCommonReader(QIODevice* io, KoOdfWriters *writers)
 MsooXmlCommonReader::~MsooXmlCommonReader()
 {
     delete m_currentTextStyleProperties;
+    delete m_currentListStyleProperties;
 }
 
 void MsooXmlCommonReader::init()
 {
     m_currentTextStyleProperties = 0;
+    m_currentListStyleProperties = 0;
     m_read_p_args = 0;
     m_lstStyleFound = false;
     m_pPr_lvl = 0;
     m_addManifestEntryForPicturesDirExecuted = false;
+    m_moveToStylesXml = false;
 }
 
 //! CASE #420
@@ -73,6 +76,10 @@ bool MsooXmlCommonReader::isDefaultTocStyle(const QString& name) const
 void MsooXmlCommonReader::setupParagraphStyle()
 {
     QString currentParagraphStyleName(mainStyles->insert(m_currentParagraphStyle));
+    if (m_moveToStylesXml) {
+        mainStyles->markStyleForStylesXml(currentParagraphStyleName);
+    }
+
     if (currentParagraphStyleName.isEmpty()) {
         currentParagraphStyleName = QLatin1String("Standard");
     }
