@@ -24,6 +24,7 @@
 #include <QSharedDataPointer>
 #include <QString>
 #include <QTextStream>
+#include <QVariant>
 #include <QVector>
 #include <QPoint>
 
@@ -41,7 +42,8 @@ class Value;
 typedef QHash<Cell, Cell> CellIndirection;
 
 /**
- * Token
+ * \ingroup Value
+ * A formula token.
  */
 class KSPREAD_EXPORT Token
 {
@@ -87,7 +89,8 @@ public:
         Percent,        ///<  %
         CurlyBra,       ///<  { (array start)
         CurlyKet,       ///<  } (array end)
-        Pipe            ///<  | (array row separator)
+        Pipe,           ///<  | (array row separator)
+        Union           ///<  ~ (union of ranges)
     };
 
     /**
@@ -262,7 +265,8 @@ protected:
 };
 
 /**
- * Class Tokens represents array of tokens.
+ * \ingroup Value
+ * An array of formula tokens.
  *
  */
 class Tokens: public QVector<Token>
@@ -281,7 +285,8 @@ protected:
 
 
 /**
- * Class Formula encapsulates a formula for a cell.
+ * \ingroup Value
+ * A formula for a cell.
  *
  * A Formula is a equations which perform calculations on values in the cells
  * and sheets. Every formula must start with an equal sign (=).
@@ -432,6 +437,7 @@ inline uint qHash(const Formula& formula)
 
 } // namespace KSpread
 
+Q_DECLARE_METATYPE(KSpread::Formula)
 Q_DECLARE_TYPEINFO(KSpread::Formula, Q_MOVABLE_TYPE);
 
 #endif // KSPREAD_FORMULA
