@@ -74,7 +74,6 @@ class OdfSavingContext;
 class PrintSettings;
 class Region;
 class RowFormat;
-class Selection;
 class Sheet;
 class SheetPrint;
 class Style;
@@ -83,12 +82,13 @@ class Validity;
 class ValidityStorage;
 class ValueStorage;
 class View;
+template<typename T> class IntervalMap;
 
 /**
  * A sheet contains several cells.
  */
 class KSPREAD_EXPORT Sheet : public KoShapeUserData, public KoShapeControllerBase,
-                             public ProtectableObject
+        public ProtectableObject
 {
     Q_OBJECT
     Q_PROPERTY(QString sheetName READ sheetName)
@@ -133,6 +133,7 @@ public:
     // KoShapeControllerBase interface
     virtual void addShape(KoShape* shape);
     virtual void removeShape(KoShape* shape);
+    virtual KoResourceManager* resourceManager() const;
 
     /**
      * \ingroup Embedding
@@ -601,27 +602,6 @@ public:
      */
     void adjustDocumentHeight(double deltaHeight);
 
-    /**
-     * \ingroup Commands
-     * Attempts to guess the title (or 'header') of a column, within a given area of the sheet
-     * This is used, for example, by the Data Sort dialog, to guess the names of columns
-     * within the selected area.  An empty string may be returned if guessColumnTitle does not think
-     * that column @p col has a title.
-     * @param area The area within the sheet to guess from
-     * @param col The column to find the title (or 'header') for.
-     */
-    QString guessColumnTitle(QRect& area, int col);
-
-    /**
-     * \ingroup Commands
-     * Attempts to guess the title (or 'header') of a row, within a given area of the sheet
-     * This is used, for example, by the Data Sort dialog, to guess the names of rows within the selected area.
-     * An empty string may be returned if guessRowTitle does not think that row @p row has a title.
-     * @param area The area within the sheet to guess from
-     * @param row The row to find the title (or 'header') for.
-     */
-    QString guessRowTitle(QRect& area, int row);
-
     //
     //END UNSORTED METHODS
     //
@@ -630,41 +610,11 @@ public:
     //BEGIN Methods related to manipulations of selected cells
     //
 
-    /**
-     * \ingroup Commands
-     * @param selection the selection of cells to work on
-     */
-    void copySelection(Selection* selection);
-
-    /**
-     * \ingroup Commands
-     * @param selection the selection of cells to work on
-     */
-    void cutSelection(Selection* selection);
-
-    /**
-     * \ingroup Commands
-     * returns the text to be copied to the clipboard
-     * @param selection the selection of cells to work on
-     */
-    QString copyAsText(Selection* selection);
-
     /**
      * \ingroup Commands
      */
     bool areaIsEmpty(const Region& area, TestType _type = Text) ;
 
-    /**
-     * \ingroup Commands
-     * Deletes all cells in the given rectangle.
-     * The display is NOT updated by this function.
-     * This function can be used to clear an area before you paste something from the clipboard
-     * in this area.
-     *
-     * @param region The region that contains the cells that should be deleted
-     */
-    void deleteCells(const Region& region);
-
     //
     //END Methods related to manipulations of selected cells
     //
@@ -885,19 +835,26 @@ protected:
     //BEGIN Methods related to the OpenDocument file format
     //
 
-    /**
-     * \ingroup OpenDocument
-     */
-    int loadRowFormatStyles(const KoXmlElement& row, int &rowIndex,
-                       OdfLoadingContext& odfContext,
-                       QHash<QString, QRegion>& rowStyleRegions,
-                       QHash<QString, QRegion>& cellStyleRegions);
+    void loadColumnNodes(const KoXmlElement& parent, int& indexCol,
+                            int& maxColumn, KoOdfLoadingContext& odfContext,
+                            QHash<QString, QRegion>& columnStyleRegions,
+                            IntervalMap<QString>& columnStyles);
+    void loadRowNodes(const KoXmlElement& parent, int& rowIndex,
+                            int& maxColumn, OdfLoadingContext& tableContext,
+                            QHash<QString, QRegion>& rowStyleRegions,
+                            QHash<QString, QRegion>& cellStyleRegions,
+                            const IntervalMap<QString>& columnStyles,
+                            const Styles& autoStyles);
 
     /**
      * \ingroup OpenDocument
      */
-    int loadRowFormatContent(const KoXmlElement& row, int &rowIndex,
-                       OdfLoadingContext& odfContext);
+    int loadRowFormat(const KoXmlElement& row, int &rowIndex,
+                       OdfLoadingContext& odfContext,
+                       QHash<QString, QRegion>& rowStyleRegions,
+                       QHash<QString, QRegion>& cellStyleRegions,
+                       const IntervalMap<QString>& columnStyles,
+                       const Styles& autoStyles);
 
     /**
      * \ingroup OpenDocument
@@ -906,7 +863,8 @@ protected:
      */
     bool loadColumnFormat(const KoXmlElement& row,
                           const KoOdfStylesReader& stylesReader, int & indexCol,
-                          QHash<QString, QRegion>& columnStyleRegions);
+                          QHash<QString, QRegion>& columnStyleRegions,
+                          IntervalMap<QString>& columnStyles);
 
     /**
      * \ingroup OpenDocument
