@@ -61,6 +61,12 @@ KWFrame::~KWFrame()
     delete m_outline;
 }
 
+void KWFrame::setTextRunAround(KWord::TextRunAround runAround, KWord::Through runThrought)
+{
+    m_runAround = runAround;
+    m_runThrough = runThrought;
+}
+
 void KWFrame::setFrameSet(KWFrameSet *fs)
 {
     if (fs == m_frameSet)
@@ -150,7 +156,7 @@ void KWFrame::saveOdf(KoShapeSavingContext &context, const KWPage &page, int pag
     m_shape->setAdditionalAttribute("draw:z-index", QString::number(effectiveZIndex));
     m_shape->setAdditionalAttribute("text:anchor-type", "page");
     m_shape->setAdditionalAttribute("text:anchor-page-number", QString::number(page.pageNumber()));
-    context.addShapeOffset(m_shape, QMatrix(1, 0, 0 , 1, 0, -pagePos));
+    context.addShapeOffset(m_shape, QTransform(1, 0, 0 , 1, 0, -pagePos));
     m_shape->saveOdf(context);
     context.removeShapeOffset(m_shape);
     m_shape->removeAdditionalAttribute("draw:z-index");
