@@ -42,7 +42,10 @@ class KoPatternBackgroundPrivate : public KoShapeBackgroundPrivate
 {
 public:
     KoPatternBackgroundPrivate()
-        : repeat(KoPatternBackground::Tiled), refPoint(KoPatternBackground::TopLeft), imageCollection(0), imageData(0)
+        : repeat(KoPatternBackground::Tiled)
+        , refPoint(KoPatternBackground::TopLeft)
+        , imageCollection(0)
+        , imageData(0)
     {
     }
 
@@ -113,7 +116,7 @@ public:
         return offset;
     }
 
-    QMatrix matrix;
+    QTransform matrix;
     KoPatternBackground::PatternRepeat repeat;
     KoPatternBackground::ReferencePoint refPoint;
     QSizeF targetImageSize;
@@ -124,6 +127,10 @@ public:
     KoImageData * imageData;
 };
 
+
+// ----------------------------------------------------------------
+
+
 KoPatternBackground::KoPatternBackground(KoImageCollection * imageCollection)
         : KoShapeBackground(*(new KoPatternBackgroundPrivate()))
 {
@@ -136,13 +143,13 @@ KoPatternBackground::~KoPatternBackground()
 {
 }
 
-void KoPatternBackground::setMatrix(const QMatrix &matrix)
+void KoPatternBackground::setTransform(const QTransform &matrix)
 {
     Q_D(KoPatternBackground);
     d->matrix = matrix;
 }
 
-QMatrix KoPatternBackground::matrix() const
+QTransform KoPatternBackground::transform() const
 {
     Q_D(const KoPatternBackground);
     return d->matrix;
@@ -300,11 +307,11 @@ void KoPatternBackground::paint(QPainter &painter, const QPainterPath &fillPath)
         QPointF offset = d->offsetFromRect(targetRect, imageSize);
 
         // create matrix for pixmap scaling
-        QMatrix matrix;
+        QTransform matrix;
         matrix.scale(scaleX, scaleY);
 
         painter.setClipPath(fillPath);
-        painter.setWorldMatrix(matrix, true);
+        painter.setWorldTransform(matrix, true);
         painter.drawTiledPixmap(targetRect, d->imageData->pixmap(imageSize.toSize()), -offset);
     } else if (d->repeat == Original) {
         QRectF sourceRect(QPointF(0, 0), d->imageData->imageSize());
@@ -405,7 +412,7 @@ bool KoPatternBackground::loadStyle(KoOdfLoadingContext & context, const QSizeF
         return false;
 
     delete d->imageData;
-    d->imageData = d->imageCollection->createImageData(href,context.store());
+    d->imageData = d->imageCollection->createImageData(href, context.store());
     if (! d->imageData)
         return false;
 
