@@ -27,7 +27,7 @@ void TestShapeContainer::testModel()
     QCOMPARE(model->childChangedCalled(), 5); // we get a generic Matrix as well as a position change...
     QCOMPARE(model->proposeMoveCalled(), 0);
 
-    shape1->setTransformation(QMatrix());
+    shape1->setTransformation(QTransform());
     QCOMPARE(model->containerChangedCalled(), 0);
     QCOMPARE(model->childChangedCalled(), 6);
     QCOMPARE(model->proposeMoveCalled(), 0);
