@@ -103,9 +103,12 @@ public:
     void createBubbleDiagram();
     void createSurfaceDiagram();
     void createGanttDiagram();
+    void applyAttributesToDataSet( DataSet* set, ChartType newCharttype );
 
     // Pointer to Axis that owns this Private instance
     Axis * const q;
+    QMap< DataSet*, KDChart::MarkerAttributes > markerAttributesBackup;//QVector< KDChart::MarkerAttributes > > markerAttributesBackup;
+    QMap< DataSet*, KDChart::MarkerAttributes > markerAttributesGlobalBackup;//QVector< KDChart::MarkerAttributes > > markerAttributesBackup;
 
     PlotArea *plotArea;
 
@@ -764,12 +767,14 @@ void Axis::Private::createScatterDiagram()
 {
     Q_ASSERT( kdScatterDiagramModel == 0 );
     Q_ASSERT( kdScatterDiagram == 0 );
+    Q_ASSERT( plotArea );
 
     kdScatterDiagramModel = new KDChartModel;
     kdScatterDiagramModel->setDataDimensions( 2 );
 
     kdScatterDiagram = new KDChart::Plotter( plotArea->kdChart(), kdPlane );
     kdScatterDiagram->setModel( kdScatterDiagramModel );
+    kdScatterDiagram->setPen( Qt::NoPen );
     registerDiagram( kdScatterDiagram );
 
     if ( isVisible )
@@ -779,7 +784,7 @@ void Axis::Private::createScatterDiagram()
     if ( !plotArea->kdChart()->coordinatePlanes().contains( kdPlane ) )
         plotArea->kdChart()->addCoordinatePlane( kdPlane );
 
-    Q_ASSERT( plotArea );
+    
     foreach ( Axis *axis, plotArea->axes() ) {
         if ( axis->dimension() == XAxisDimension )
             if ( axis->isVisible() )
@@ -790,6 +795,19 @@ void Axis::Private::createScatterDiagram()
     KDChart::ThreeDLineAttributes attributes( kdScatterDiagram->threeDLineAttributes() );
     attributes.setEnabled( plotArea->isThreeD() );
     kdScatterDiagram->setThreeDLineAttributes( attributes );
+    
+    KDChart::DataValueAttributes dva( kdScatterDiagram->dataValueAttributes() );
+    dva.setVisible( true );
+    
+    KDChart::TextAttributes ta( dva.textAttributes() );
+    ta.setVisible( true );
+    dva.setTextAttributes( ta );
+
+    KDChart::MarkerAttributes ma( dva.markerAttributes() );
+    ma.setVisible( true );
+    dva.setMarkerAttributes( ma );
+
+    kdScatterDiagram->setDataValueAttributes( dva );
 
     plotArea->parent()->legend()->kdLegend()->addDiagram( kdScatterDiagram );
 }
@@ -834,6 +852,7 @@ void Axis::Private::createBubbleDiagram()
 {
     Q_ASSERT( kdBubbleDiagramModel == 0 );
     Q_ASSERT( kdBubbleDiagram == 0 );
+    Q_ASSERT( plotArea );
 
     kdBubbleDiagramModel = new KDChartModel;
     kdBubbleDiagramModel->setDataDimensions( 2 );
@@ -843,15 +862,16 @@ void Axis::Private::createBubbleDiagram()
     
     registerDiagram( kdBubbleDiagram );
     
-    kdPlane->addDiagram( kdBubbleDiagram );
+    kdPlane->addDiagram( kdBubbleDiagram );    
 
     if ( !plotArea->kdChart()->coordinatePlanes().contains( kdPlane ) )
-        plotArea->kdChart()->addCoordinatePlane( kdPlane );
+        plotArea->kdChart()->addCoordinatePlane( kdPlane );    
     
-    //foreach ( Axis *axis, plotArea->axes() ) {
-    //    if ( axis->isVisible() )
-    //        kdBubbleDiagram->addAxis( axis->kdAxis() );
-    //}
+    foreach ( Axis *axis, plotArea->axes() ) {
+        //if ( axis->dimension() == XAxisDimension )
+            if ( axis->isVisible() )
+                kdBubbleDiagram->addAxis( axis->kdAxis() );
+    }
     
      // disable the connecting line
     //kdBubbleDiagram->setPen( QPen( Qt::black, 0.0 ) );
@@ -867,14 +887,8 @@ void Axis::Private::createBubbleDiagram()
     KDChart::MarkerAttributes ma( dva.markerAttributes() );
     ma.setVisible( true );
     ma.setMarkerStyle( KDChart::MarkerAttributes::MarkerRing );
-    //ma.setMarkerSize( QSizeF(30.0,30.0) );
     dva.setMarkerAttributes( ma );
 
-    //KDChart::RelativePosition pos( dva.positivePosition() );
-    //pos.setAlignment( Qt::AlignCenter );
-    //pos.setHorizontalPadding(0);
-    //dva.setPositivePosition( pos );
-
     kdBubbleDiagram->setDataValueAttributes( dva );
 
     plotArea->parent()->legend()->kdLegend()->addDiagram( kdBubbleDiagram );
@@ -1911,7 +1925,7 @@ void Axis::plotAreaChartTypeChanged( ChartType newChartType )
         foreach ( DataSet *dataSet, d->dataSets ) {
             if ( dataSet->chartType() != LastChartType ) {
                 dataSet->setChartType( LastChartType );
-                dataSet->setChartSubType( NoChartSubtype );
+                dataSet->setChartSubType( NoChartSubtype );                
             }
         }
     }
@@ -1920,8 +1934,12 @@ void Axis::plotAreaChartTypeChanged( ChartType newChartType )
         if ( dataSet->chartType() != LastChartType )
             continue;
 
+        Qt::PenStyle newPenStyle = newDiagram->pen().style();
+        QPen newPen = dataSet->pen();
+        newPen.setStyle( newPenStyle );
+        dataSet->setPen(  newPen );
         dataSet->setKdDiagram( newDiagram );
-        newModel->addDataSet( dataSet );
+        newModel->addDataSet( dataSet );        
         if ( oldModel && *oldModel ) {
             const int dataSetCount = (*oldModel)->dataDirection() == Qt::Vertical
                                      ? (*oldModel)->columnCount() : (*oldModel)->rowCount();
