@@ -1,5 +1,6 @@
 /* This file is part of the KDE project
  * Copyright (C) 2007 Pierre Ducroquet <pinaraf@gmail.com>
+ * Copyright (C) 2008 Thorsten Zachmann <zachmann@kde.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -20,23 +21,28 @@
 #define INFOVARIABLE_H
 
 #include <KoVariable.h>
-#include <QString>
 
 /**
  * This is a KoVariable for document information.
  */
-class InfoVariable : public KoVariable {
+class InfoVariable : public KoVariable
+{
 public:
     /**
      * Constructor.
      */
     InfoVariable();
 
-    void setProperties(const KoProperties *props);
+    void readProperties(const KoProperties *props);
 
     void propertyChanged(Property property, const QVariant &value);
-    
-    void saveOdf (KoShapeSavingContext & context);
+
+    ///reimplemented
+    void saveOdf(KoShapeSavingContext & context);
+
+    ///reimplemented
+    bool loadOdf(const KoXmlElement & element, KoShapeLoadingContext & context);
+
 private:
     KoInlineObject::Property m_type;
 };
